Welcome to django-teamwork’s documentation! — django-teamwork 0.0.1 documentation

# Welcome to django-teamwork’s documentation!

django-teamwork is a Django app that offers an authorization backend with support for per-object permissions based on combinations of Teams, Roles, and Policies.

- Source code on GitHub
- Build status on travis-ci ()
- Latest documentation on Read The Docs (source)

Contents:

- Overview
  - What is django-teamwork?
- Getting Started
  - Installation
  - Configuration
- Usage
  - Checking permissions for a user and content object
  - Using the `get_object_or_404_or_403` shortcut
  - Base policy in `settings.py`
  - Setting a Policy on a Site
  - Setting a Policy on a content object
  - Creating Teams and Roles
  - Granting Team ownership of content Objects
  - Assigning Roles to Users
  - Filtering permissions with per-object logic
  - Supporting content hierarchies and Permission inheritance
- Contributing
  - Hacking notes
- TODO
  - Use Cases / Specs

# Indices and tables

- Index
- Search Page